Configuration — BCI-Framework documentation

# Configuration

class `bci_framework.framework.configuration.` `ConfigurationFrame`(*args, **kwargs)

  Auxiliar window with configuration options.

  `connect`() → None

    Connect events.

  `remove_records`(*args, **kwargs) → None

    Clear the directory with records.

  `reset_connections`() → None

    Remove user modified connection configurations.

  `reset_montages`(*args, **kwargs) → None

    Remove user defined montages.

  `reset_projects`(*args, **kwargs) → None

    Remove user projects nad copy the default projects.

  `reset_section`(section: str) → None

    Overwrite user section with default section.

  `restore_projects`(*args, **kwargs) → None

    Copy defautl project into the user projects directory.

  `show`() → None

    Show frame.